@@ -1,5 +1,5 @@
 from .brent import minimize as minimize_scalar
 from .brent import maximize as maximize_scalar
 
-from .tnc import minimize
-from .tnc import maximize
+from .bfgs import minimize
+from .bfgs import maximize
